@@ -1,6 +1,5 @@
 package io.gitlab.arturbosch.detekt.api
 
-import io.gitlab.arturbosch.detekt.api.internal.BaseRule
 import org.jetbrains.kotlin.psi.KtFile
 
 /**
@@ -8,6 +7,8 @@ import org.jetbrains.kotlin.psi.KtFile
  * Can be used to combine different rules which do similar work like
  * scanning the source code line by line to increase performance.
  */
+@Deprecated("multi rules are much more difficult to maintain and support will be removed in the future")
+@Suppress("ViolatesTypeResolutionRequirements")
 abstract class MultiRule : BaseRule() {
 
     abstract val rules: List<Rule>
