@@ -15,15 +15,22 @@ fun whichOS(): String = System.getProperty("os.name")
  */
 fun whichJava(): String = System.getProperty("java.runtime.version")
 
+/**
+ * Returns the version of Kotlin that detekt was compiled with
+ */
+fun whichKotlin(): String = getManifestValue("KotlinImplementationVersion")
+
 /**
  * Returns the bundled detekt version.
  */
-fun whichDetekt(): String? {
+fun whichDetekt(): String = getManifestValue("DetektVersion")
+
+private fun getManifestValue(key: String): String {
     fun readVersion(resource: URL): String? = resource.openSafeStream()
-        .use { Manifest(it).mainAttributes.getValue("DetektVersion") }
+        .use { Manifest(it).mainAttributes.getValue(key) }
 
     return Extension::class.java.classLoader.getResources("META-INF/MANIFEST.MF")
         .asSequence()
         .mapNotNull { runCatching { readVersion(it) }.getOrNull() }
-        .firstOrNull()
+        .first()
 }
