@@ -5,17 +5,18 @@ import io.github.detekt.test.utils.createTempFileForTest
 import io.gitlab.arturbosch.detekt.cli.parseArguments
 import org.assertj.core.api.Assertions.assertThat
 import org.junit.jupiter.api.Test
-import java.nio.file.Files
+import kotlin.io.path.deleteExisting
+import kotlin.io.path.readLines
 
 class ConfigExporterSpec {
 
     @Test
     fun `should export the given config`() {
-        val tmpConfig = createTempFileForTest("ConfigPrinterSpec", ".yml").also { Files.delete(it) }
+        val tmpConfig = createTempFileForTest("ConfigPrinterSpec", ".yml").also { it.deleteExisting() }
         val cliArgs = parseArguments(arrayOf("--config", tmpConfig.toString()))
 
         ConfigExporter(cliArgs, NullPrintStream()).execute()
 
-        assertThat(Files.readAllLines(tmpConfig)).isNotEmpty
+        assertThat(tmpConfig.readLines()).isNotEmpty
     }
 }
