@@ -5,11 +5,12 @@ import io.gitlab.arturbosch.detekt.core.createNullLoggingSpec
 import io.gitlab.arturbosch.detekt.core.rules.RuleSetLocator
 import io.gitlab.arturbosch.detekt.core.tooling.withSettings
 import org.assertj.core.api.Assertions.assertThat
-import org.spekframework.spek2.Spek
+import org.junit.jupiter.api.Test
 
-internal class LoadingSpec : Spek({
+class LoadingSpec {
 
-    test("extensions can be excluded via ExtensionSpec") {
+    @Test
+    fun `extensions can be excluded via ExtensionSpec`() {
         val providers = createNullLoggingSpec {
             extensions {
                 disableExtension("SampleConfigValidator")
@@ -20,7 +21,8 @@ internal class LoadingSpec : Spek({
             .doesNotContain("SampleConfigValidator")
     }
 
-    test("RuleSetProvider can be excluded via ExtensionSpec") {
+    @Test
+    fun `RuleSetProvider can be excluded via ExtensionSpec`() {
         val providers = createNullLoggingSpec {
             extensions {
                 disableExtension("sample-rule-set")
@@ -30,4 +32,4 @@ internal class LoadingSpec : Spek({
         assertThat(providers.map { it.ruleSetId })
             .doesNotContain("sample-rule-set")
     }
-})
+}
