@@ -9,7 +9,7 @@ import org.assertj.core.api.Assertions.assertThat
 internal object AutoCorrectableIssueAssert {
 
     fun isReportNull(report: ConsoleReport) {
-        val config = TestConfig(mapOf("maxIssues" to "0", "excludeCorrectable" to "true"))
+        val config = TestConfig("maxIssues" to "0", "excludeCorrectable" to "true")
         report.init(config)
         val correctableCodeSmell = createCorrectableFinding()
         val detektionWithCorrectableSmell = TestDetektion(correctableCodeSmell)
