@@ -1,6 +1,11 @@
 plugins {
     alias(libs.plugins.shadow)
     id("module")
+    application
+}
+
+application {
+    mainClass = "io.gitlab.arturbosch.detekt.generator.Main"
 }
 
 dependencies {
@@ -74,6 +79,8 @@ val generateDocumentation by tasks.registering(JavaExec::class) {
         configDir,
         "--cli-options",
         cliOptionsFile,
+        "--replace",
+        "<ktlintVersion/>=${libs.versions.ktlint.get()}"
     )
 }
 
