@@ -1,6 +1,8 @@
 package io.github.detekt.metrics
 
 import io.gitlab.arturbosch.detekt.api.DetektVisitor
+import io.gitlab.arturbosch.detekt.rules.isElseIf
+import org.jetbrains.kotlin.KtNodeTypes
 import org.jetbrains.kotlin.com.intellij.openapi.util.Key
 import org.jetbrains.kotlin.com.intellij.psi.tree.IElementType
 import org.jetbrains.kotlin.lexer.KtTokens
@@ -8,6 +10,7 @@ import org.jetbrains.kotlin.psi.KtBinaryExpression
 import org.jetbrains.kotlin.psi.KtBreakExpression
 import org.jetbrains.kotlin.psi.KtCallExpression
 import org.jetbrains.kotlin.psi.KtCatchClause
+import org.jetbrains.kotlin.psi.KtContainerNodeForControlStructureBody
 import org.jetbrains.kotlin.psi.KtContinueExpression
 import org.jetbrains.kotlin.psi.KtDoWhileExpression
 import org.jetbrains.kotlin.psi.KtElement
@@ -88,9 +91,34 @@ class CognitiveComplexity private constructor() : DetektVisitor() {
             nestAround { super.visitForExpression(expression) }
         }
 
-        override fun visitIfExpression(expression: KtIfExpression) {
-            addComplexity()
-            nestAround { super.visitIfExpression(expression) }
+        override fun visitKtElement(element: KtElement) {
+            val parent = element.parent
+            if (element is KtContainerNodeForControlStructureBody && parent is KtIfExpression) {
+                when (element.node.elementType) {
+                    KtNodeTypes.THEN -> {
+                        if (parent.isElseIf()) {
+                            complexity++
+                        } else {
+                            addComplexity()
+                        }
+                        nestAround { super.visitKtElement(element) }
+                    }
+
+                    KtNodeTypes.ELSE -> {
+                        if (element.expression is KtIfExpression) {
+                            super.visitKtElement(element)
+                        } else {
+                            complexity++
+                            nestAround { super.visitKtElement(element) }
+                        }
+                    }
+
+                    else ->
+                        super.visitKtElement(element)
+                }
+            } else {
+                super.visitKtElement(element)
+            }
         }
 
         override fun visitBreakExpression(expression: KtBreakExpression) {
