@@ -7,8 +7,10 @@ import org.jetbrains.kotlin.cli.jvm.compiler.KotlinCoreEnvironment
 import org.jetbrains.kotlin.com.intellij.openapi.util.text.StringUtilRt
 import org.jetbrains.kotlin.psi.KtFile
 import org.jetbrains.kotlin.psi.KtPsiFactory
-import java.nio.file.Files
 import java.nio.file.Path
+import kotlin.io.path.absolute
+import kotlin.io.path.isRegularFile
+import kotlin.io.path.readText
 
 open class KtCompiler(
     protected val environment: KotlinCoreEnvironment = createKotlinCoreEnvironment(printStream = System.err)
@@ -17,15 +19,15 @@ open class KtCompiler(
     protected val psiFileFactory = KtPsiFactory(environment.project, markGenerated = false)
 
     fun compile(basePath: Path?, path: Path): KtFile {
-        require(Files.isRegularFile(path)) { "Given sub path ($path) should be a regular file!" }
-        val content = path.toFile().readText()
+        require(path.isRegularFile()) { "Given sub path ($path) should be a regular file!" }
+        val content = path.readText()
         return createKtFile(content, basePath, path)
     }
 
     fun createKtFile(content: String, basePath: Path?, path: Path): KtFile {
-        require(Files.isRegularFile(path)) { "Given sub path ($path) should be a regular file!" }
+        require(path.isRegularFile()) { "Given sub path ($path) should be a regular file!" }
 
-        val normalizedAbsolutePath = path.toAbsolutePath().normalize()
+        val normalizedAbsolutePath = path.absolute().normalize()
         val lineSeparator = content.determineLineSeparator()
 
         val psiFile = psiFileFactory.createPhysicalFile(
@@ -35,9 +37,9 @@ open class KtCompiler(
 
         return psiFile.apply {
             putUserData(LINE_SEPARATOR, lineSeparator)
-            val normalizedBasePath = basePath?.toAbsolutePath()?.normalize()
+            val normalizedBasePath = basePath?.absolute()?.normalize()
             normalizedBasePath?.relativize(normalizedAbsolutePath)?.let { relativePath ->
-                putUserData(BASE_PATH, normalizedBasePath.toAbsolutePath().toString())
+                putUserData(BASE_PATH, normalizedBasePath.absolute().toString())
                 putUserData(RELATIVE_PATH, relativePath.toString())
             }
         }
