@@ -7,7 +7,14 @@ import org.jetbrains.kotlin.psi.KtModifierListOwner
 import org.jetbrains.kotlin.psi.psiUtil.isPublic
 
 fun KtModifierListOwner.isPublicNotOverridden() =
-    isPublic && !isOverride()
+    isPublicNotOverridden(false)
+
+fun KtModifierListOwner.isPublicNotOverridden(considerProtectedAsPublic: Boolean) =
+    if (considerProtectedAsPublic) {
+        isPublic || isProtected()
+    } else {
+        isPublic
+    } && !isOverride()
 
 fun KtModifierListOwner.isAbstract() = hasModifier(KtTokens.ABSTRACT_KEYWORD)
 
@@ -30,3 +37,5 @@ fun KtModifierListOwner.isInline() = hasModifier(KtTokens.INLINE_KEYWORD)
 fun KtModifierListOwner.isExpect() = hasModifier(KtTokens.EXPECT_KEYWORD)
 
 fun KtModifierListOwner.isActual() = hasModifier(KtTokens.ACTUAL_KEYWORD)
+
+fun KtModifierListOwner.isProtected() = hasModifier(KtTokens.PROTECTED_KEYWORD)
