@@ -24,12 +24,6 @@ class KtFilesSpec {
             assertThat(filename).isEqualTo("C")
         }
 
-        @Test
-        fun `should remove common_kt suffix`() {
-            val filename = makeFile("C.common.kt").fileNameWithoutSuffix()
-            assertThat(filename).isEqualTo("C")
-        }
-
         @Test
         fun `should not remove non kotlin suffixes`() {
             val filename = makeFile("C.java").fileNameWithoutSuffix()
