@@ -12,6 +12,7 @@ import io.gitlab.arturbosch.detekt.api.internal.Configuration
 import io.gitlab.arturbosch.detekt.api.internal.RequiresTypeResolution
 import org.jetbrains.kotlin.psi.KtCallExpression
 import org.jetbrains.kotlin.psi.KtLambdaArgument
+import org.jetbrains.kotlin.resolve.calls.components.isVararg
 import org.jetbrains.kotlin.resolve.calls.util.getParameterForArgument
 import org.jetbrains.kotlin.resolve.calls.util.getResolvedCall
 
@@ -58,7 +59,6 @@ class NamedArguments(config: Config = Config.empty) : Rule(config) {
         }
     }
 
-    @Suppress("ReturnCount")
     private fun KtCallExpression.canNameArguments(): Boolean {
         val resolvedCall = getResolvedCall(bindingContext) ?: return false
         if (!resolvedCall.candidateDescriptor.hasStableParameterNames()) return false
@@ -66,17 +66,14 @@ class NamedArguments(config: Config = Config.empty) : Rule(config) {
         val unnamedArguments = valueArguments.mapNotNull { argument ->
             if (argument.isNamed() || argument is KtLambdaArgument) return@mapNotNull null
             val parameter = resolvedCall.getParameterForArgument(argument) ?: return@mapNotNull null
-            if (ignoreArgumentsMatchingNames &&
-                parameter.name.asString() == argument.getArgumentExpression()?.text
-            ) {
+            if (ignoreArgumentsMatchingNames && parameter.name.asString() == argument.getArgumentExpression()?.text) {
                 return@mapNotNull null
             }
             argument to parameter
         }
-        if (unnamedArguments.isEmpty()) return false
 
-        return unnamedArguments.all { (argument, parameter) ->
-            argument.getSpreadElement() != null || parameter.varargElementType == null
-        }
+        return unnamedArguments.isNotEmpty() &&
+            unnamedArguments.count { (argument, _) -> argument.isSpread } <= 1 &&
+            unnamedArguments.all { (argument, parameter) -> argument.isSpread || !parameter.isVararg }
     }
 }
