@@ -11,7 +11,6 @@ import io.gitlab.arturbosch.detekt.api.internal.RequiresTypeResolution
 import org.jetbrains.kotlin.com.intellij.psi.PsiElement
 import org.jetbrains.kotlin.diagnostics.Errors
 import org.jetbrains.kotlin.psi.KtNamedDeclaration
-import org.jetbrains.kotlin.resolve.BindingContext
 
 /**
  * Deprecated elements are expected to be removed in the future. Alternatives should be found if possible.
@@ -30,10 +29,10 @@ class Deprecation(config: Config) : Rule(config) {
     override val defaultRuleIdAliases = setOf("DEPRECATION")
 
     override fun visitElement(element: PsiElement) {
-        if (bindingContext == BindingContext.EMPTY) return
-        if (hasDeprecationCompilerWarnings(element)) {
+        val diagnostic = hasDeprecationCompilerWarnings(element)
+        if (diagnostic != null) {
             val entity = if (element is KtNamedDeclaration) Entity.atName(element) else Entity.from(element)
-            report(CodeSmell(issue, entity, "${element.text} is deprecated."))
+            report(CodeSmell(issue, entity, """${element.text} is deprecated with message "${diagnostic.b}""""))
         }
         super.visitElement(element)
     }
@@ -41,5 +40,6 @@ class Deprecation(config: Config) : Rule(config) {
     private fun hasDeprecationCompilerWarnings(element: PsiElement) =
         bindingContext.diagnostics
             .forElement(element)
-            .any { it.factory == Errors.DEPRECATION }
+            .firstOrNull { it.factory == Errors.DEPRECATION }
+            ?.let { Errors.DEPRECATION.cast(it) }
 }
