@@ -6,6 +6,8 @@ import org.assertj.core.api.Assertions.assertThat
 import org.junit.jupiter.api.Test
 
 class DuplicateCaseInWhenExpressionSpec {
+
+    @Suppress("DEPRECATION")
     private val subject = DuplicateCaseInWhenExpression(Config.empty)
 
     @Test
@@ -20,7 +22,7 @@ class DuplicateCaseInWhenExpressionSpec {
                     else -> println()
                 }
             }
-        """
+        """.trimIndent()
         val result = subject.compileAndLint(code)
         assertThat(result).hasSize(1)
         assertThat(result.first().message).isEqualTo("When expression has multiple case statements for 1; 1, 2.")
@@ -35,7 +37,7 @@ class DuplicateCaseInWhenExpressionSpec {
                     else -> println()
                 }
             }
-        """
+        """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
 }
