@@ -136,4 +136,21 @@ class EqualsAlwaysReturnsTrueOrFalseSpec {
         """.trimIndent()
         assertThat(subject.compileAndLint(code)).isEmpty()
     }
+
+    @Test
+    fun `doesn't report when custom method named equals with extension receiver is used - #6569`() {
+        val code = """
+            open class Base1 {
+                open fun Base1.equals(other: Any?): Boolean {
+                    return false
+                }
+            }
+            class A1 : Base1() {
+                override fun Base1.equals(other: Any?): Boolean {
+                    return true
+                }
+            }
+        """.trimIndent()
+        assertThat(subject.compileAndLint(code)).isEmpty()
+    }
 }
