@@ -13,6 +13,7 @@ import io.gitlab.arturbosch.detekt.api.internal.Configuration
 import io.gitlab.arturbosch.detekt.rules.isOverride
 import io.gitlab.arturbosch.detekt.rules.naming.util.isContainingExcludedClassOrObject
 import org.jetbrains.kotlin.psi.KtNamedFunction
+import org.jetbrains.kotlin.psi.KtUserType
 
 /**
  * Reports function names that do not follow the specified naming convention.
@@ -38,19 +39,21 @@ class FunctionNaming(config: Config = Config.empty) : Rule(config) {
     private val excludeClassPattern: Regex by config("$^", String::toRegex)
 
     @Configuration("ignores functions that have the override modifier")
+    @Deprecated("This configuration is ignored and will be removed in the future")
+    @Suppress("UnusedPrivateMember")
     private val ignoreOverridden: Boolean by config(true)
 
     override fun visitNamedFunction(function: KtNamedFunction) {
         super.visitNamedFunction(function)
 
-        if (ignoreOverridden && function.isOverride()) {
+        if (function.isOverride()) {
             return
         }
 
         val functionName = function.nameIdentifier?.text ?: return
         if (!function.isContainingExcludedClassOrObject(excludeClassPattern) &&
             !functionName.matches(functionPattern) &&
-            functionName != function.typeReference?.text
+            functionName != function.returnTypeName()
         ) {
             report(
                 CodeSmell(
@@ -62,9 +65,10 @@ class FunctionNaming(config: Config = Config.empty) : Rule(config) {
         }
     }
 
+    private fun KtNamedFunction.returnTypeName() = (typeReference?.typeElement as? KtUserType)?.referencedName
+
     companion object {
         const val FUNCTION_PATTERN = "functionPattern"
         const val EXCLUDE_CLASS_PATTERN = "excludeClassPattern"
-        const val IGNORE_OVERRIDDEN = "ignoreOverridden"
     }
 }
