@@ -61,6 +61,9 @@ class MatchingDeclarationName(config: Config = Config.empty) : Rule(config) {
     @Configuration("name should only be checked if the file starts with a class or object")
     private val mustBeFirst: Boolean by config(true)
 
+    @Configuration("kotlin multiplatform targets, used to allow file names like `MyClass.jvm.kt`")
+    private val multiplatformTargets: List<String> by config(COMMON_KOTLIN_KMP_PLATFORM_TARGET_SUFFIXES)
+
     override fun visitKtFile(file: KtFile) {
         val declarations = file.declarations
             .asSequence()
@@ -77,7 +80,7 @@ class MatchingDeclarationName(config: Config = Config.empty) : Rule(config) {
         if (declarations.size == 1 && matchesFirstClassOrObjectCondition()) {
             val declaration = declarations.first()
             val declarationName = declaration.name
-            val filename = file.fileNameWithoutSuffix()
+            val filename = file.fileNameWithoutSuffix(multiplatformTargets)
             if (declarationName != filename && hasNoMatchingTypeAlias(filename)) {
                 val entity = Entity.atName(declaration).copy(ktElement = file)
                 report(
@@ -91,4 +94,20 @@ class MatchingDeclarationName(config: Config = Config.empty) : Rule(config) {
             }
         }
     }
+
+    companion object {
+
+        private val COMMON_KOTLIN_KMP_PLATFORM_TARGET_SUFFIXES = listOf(
+            "ios",
+            "android",
+            "js",
+            "jvm",
+            "native",
+            "iosArm64",
+            "iosX64",
+            "macosX64",
+            "mingwX64",
+            "linuxX64"
+        )
+    }
 }
