@@ -14,7 +14,9 @@ import io.gitlab.arturbosch.detekt.api.internal.Configuration
 import io.gitlab.arturbosch.detekt.api.internal.RequiresTypeResolution
 import io.gitlab.arturbosch.detekt.api.valuesWithReason
 import org.jetbrains.kotlin.descriptors.CallableDescriptor
+import org.jetbrains.kotlin.descriptors.FunctionDescriptor
 import org.jetbrains.kotlin.descriptors.PropertyDescriptor
+import org.jetbrains.kotlin.descriptors.SyntheticPropertyDescriptor
 import org.jetbrains.kotlin.psi.KtBinaryExpression
 import org.jetbrains.kotlin.psi.KtCallExpression
 import org.jetbrains.kotlin.psi.KtCallableReferenceExpression
@@ -23,10 +25,9 @@ import org.jetbrains.kotlin.psi.KtExpression
 import org.jetbrains.kotlin.psi.KtPostfixExpression
 import org.jetbrains.kotlin.psi.KtPrefixExpression
 import org.jetbrains.kotlin.psi.psiUtil.isDotSelector
-import org.jetbrains.kotlin.psi2ir.unwrappedGetMethod
-import org.jetbrains.kotlin.psi2ir.unwrappedSetMethod
 import org.jetbrains.kotlin.resolve.calls.util.getCalleeExpressionIfAny
 import org.jetbrains.kotlin.resolve.calls.util.getResolvedCall
+import org.jetbrains.kotlin.resolve.descriptorUtil.overriddenTreeUniqueAsSequence
 
 /**
  * Reports all method or constructor invocations that are forbidden.
@@ -76,6 +77,12 @@ class ForbiddenMethodCall(config: Config = Config.empty) : Rule(config) {
         list.map { Forbidden(fromFunctionSignature(it.value), it.reason) }
     }
 
+    private val PropertyDescriptor.unwrappedGetMethod: FunctionDescriptor?
+        get() = if (this is SyntheticPropertyDescriptor) this.getMethod else getter
+
+    private val PropertyDescriptor.unwrappedSetMethod: FunctionDescriptor?
+        get() = if (this is SyntheticPropertyDescriptor) this.setMethod else setter
+
     override fun visitCallExpression(expression: KtCallExpression) {
         super.visitCallExpression(expression)
         check(expression)
@@ -109,14 +116,20 @@ class ForbiddenMethodCall(config: Config = Config.empty) : Rule(config) {
     }
 
     private fun check(expression: KtExpression) {
-        val descriptors = expression.getResolvedCall(bindingContext)?.resultingDescriptor?.let {
-            val foundDescriptors = if (it is PropertyDescriptor) {
-                listOfNotNull(it.unwrappedGetMethod, it.unwrappedSetMethod)
-            } else {
-                listOf(it)
-            }
-            foundDescriptors + foundDescriptors.flatMap(CallableDescriptor::getOverriddenDescriptors)
-        } ?: return
+        val descriptors: Set<CallableDescriptor> =
+            expression.getResolvedCall(bindingContext)?.resultingDescriptor?.let { callableDescriptor ->
+                val foundDescriptors = if (callableDescriptor is PropertyDescriptor) {
+                    setOfNotNull(
+                        callableDescriptor.unwrappedGetMethod,
+                        callableDescriptor.unwrappedSetMethod
+                    )
+                } else {
+                    setOf(callableDescriptor)
+                }
+                foundDescriptors.flatMapTo(mutableSetOf()) {
+                    it.overriddenTreeUniqueAsSequence(true).toSet()
+                }
+            } ?: return
 
         for (descriptor in descriptors) {
             methods.find { it.value.match(descriptor) }?.let { forbidden ->
