@@ -8,12 +8,12 @@ import org.jetbrains.kotlin.psi.psiUtil.elementsInRange
 import org.jetbrains.kotlin.psi.psiUtil.getNonStrictParentOfType
 
 /**
- * Util function to search for the first [KtElement] in the parents of
+ * Util function to search for the [KtElement]s in the parents of
  * the given [line] from a given offset in a [KtFile].
  */
-internal fun findFirstKtElementInParents(file: KtFile, offset: Int, line: String): PsiElement? {
+internal fun findKtElementInParents(file: KtFile, offset: Int, line: String): Sequence<PsiElement> {
     return file.elementsInRange(TextRange.create(offset - line.length, offset))
+        .asSequence()
         .plus(file.findElementAt(offset))
         .mapNotNull { it?.getNonStrictParentOfType() }
-        .firstOrNull()
 }
