@@ -2,9 +2,9 @@ package io.gitlab.arturbosch.detekt.rules.style
 
 import io.gitlab.arturbosch.detekt.api.Config
 import io.gitlab.arturbosch.detekt.test.TestConfig
+import io.gitlab.arturbosch.detekt.test.assertThat
 import io.gitlab.arturbosch.detekt.test.compileAndLint
 import io.gitlab.arturbosch.detekt.test.lint
-import org.assertj.core.api.Assertions.assertThat
 import org.junit.jupiter.api.Nested
 import org.junit.jupiter.api.Test
 
@@ -19,9 +19,18 @@ class ModifierOrderSpec {
 
         @Test
         fun `should report incorrectly ordered modifiers`() {
-            assertThat(subject.compileAndLint(bad1)).hasSize(1)
-            assertThat(subject.lint(bad2)).hasSize(1)
-            assertThat(subject.lint(bad3)).hasSize(1)
+            subject.compileAndLint(bad1).let {
+                assertThat(it).hasSize(1)
+                assertThat(it[0]).hasMessage("Modifier order should be: internal data")
+            }
+            subject.lint(bad2).let {
+                assertThat(it).hasSize(1)
+                assertThat(it[0]).hasMessage("Modifier order should be: private actual")
+            }
+            subject.lint(bad3).let {
+                assertThat(it).hasSize(1)
+                assertThat(it[0]).hasMessage("Modifier order should be: expect annotation")
+            }
         }
 
         @Test
@@ -29,11 +38,12 @@ class ModifierOrderSpec {
             assertThat(subject.compileAndLint("internal data class Test(val test: String)")).isEmpty()
             assertThat(subject.lint("private actual class Test(val test: String)")).isEmpty()
             assertThat(subject.lint("expect annotation class Test")).isEmpty()
+            assertThat(subject.lint("private /* comment */ data class Test(val test: String)")).isEmpty()
         }
 
         @Test
         fun `should not report issues if inactive`() {
-            val rule = ModifierOrder(TestConfig(mapOf(Config.ACTIVE_KEY to "false")))
+            val rule = ModifierOrder(TestConfig(Config.ACTIVE_KEY to "false"))
             assertThat(rule.compileAndLint(bad1)).isEmpty()
             assertThat(rule.lint(bad2)).isEmpty()
             assertThat(rule.lint(bad3)).isEmpty()
