@@ -2,9 +2,9 @@ package io.github.detekt.test.utils
 
 import java.net.URI
 import java.net.URL
-import java.nio.file.Files
 import java.nio.file.Path
-import java.nio.file.Paths
+import kotlin.io.path.readLines
+import kotlin.io.path.toPath
 
 internal object Resources
 
@@ -15,9 +15,9 @@ fun resourceUrl(name: String): URL {
 
 fun resource(name: String): URI = resourceUrl(name).toURI()
 
-fun resourceAsPath(name: String): Path = Paths.get(resource(name))
+fun resourceAsPath(name: String): Path = resource(name).toPath()
 
 fun readResourceContent(name: String): String {
     val path = resourceAsPath(name)
-    return Files.readAllLines(path).joinToString("\n") + "\n"
+    return path.readLines().joinToString("\n") + "\n"
 }
