@@ -119,19 +119,19 @@ class FindingAssert(val actual: Finding?) : AbstractAssert<FindingAssert, Findin
 
     fun hasSourceLocation(line: Int, column: Int) = apply {
         val expectedLocation = SourceLocation(line, column)
-        val actualLocation = actual.location.source
+        val actualLocation = actual?.location?.source
         if (actualLocation != expectedLocation) {
             failWithMessage("Expected source location to be $expectedLocation but was $actualLocation")
         }
     }
 
     fun hasMessage(expectedMessage: String) = apply {
-        if (expectedMessage.isNotBlank() && actual.message.isBlank()) {
+        if (expectedMessage.isNotBlank() && actual?.message.isNullOrBlank()) {
             failWithMessage("Expected message <$expectedMessage> but finding has no message")
         }
 
-        if (!actual.message.trim().equals(expectedMessage.trim(), ignoreCase = true)) {
-            failWithMessage("Expected message <$expectedMessage> but actual message was <${actual.message}>")
+        if (!actual?.message?.trim().equals(expectedMessage.trim(), ignoreCase = true)) {
+            failWithMessage("Expected message <$expectedMessage> but actual message was <${actual?.message}>")
         }
     }
 }
