@@ -7,7 +7,7 @@ import java.nio.file.Path
 @ProcessingModelDsl
 class ConfigSpecBuilder : Builder<ConfigSpec> {
 
-    var shouldValidateBeforeAnalysis: Boolean = true
+    var shouldValidateBeforeAnalysis: Boolean? = null
     var knownPatterns: Collection<String> = emptyList()
 
     var useDefaultConfig: Boolean = false // false to be backwards compatible in 1.X
@@ -24,7 +24,7 @@ class ConfigSpecBuilder : Builder<ConfigSpec> {
 }
 
 private data class ConfigModel(
-    override val shouldValidateBeforeAnalysis: Boolean,
+    override val shouldValidateBeforeAnalysis: Boolean?,
     override val knownPatterns: Collection<String>,
     override val useDefaultConfig: Boolean,
     override val resources: Collection<URL>,
