@@ -5,7 +5,9 @@ import io.gitlab.arturbosch.detekt.rules.KotlinCoreEnvironmentTest
 import io.gitlab.arturbosch.detekt.test.getContextForPaths
 import org.assertj.core.api.Assertions.assertThat
 import org.jetbrains.kotlin.cli.jvm.compiler.KotlinCoreEnvironment
+import org.jetbrains.kotlin.psi.KtClass
 import org.jetbrains.kotlin.psi.KtNamedFunction
+import org.jetbrains.kotlin.psi.psiUtil.findFunctionByName
 import org.jetbrains.kotlin.resolve.BindingContext
 import org.junit.jupiter.api.DisplayName
 import org.junit.jupiter.api.DynamicTest
@@ -107,6 +109,22 @@ class FunctionMatcherSpec(private val env: KotlinCoreEnvironment) {
             assertThat(methodSignature.match(function, bindingContext)).isEqualTo(result)
         }
 
+        @DisplayName("When toString")
+        @ParameterizedTest(name = "in case {0} it return {1}")
+        @CsvSource(
+            "fun toString() = Unit,                            true",
+            "fun toString(hello: String) = Unit,               true",
+            "'fun toString(hello: String, world: Int) = Unit', true",
+            "fun compare() = Unit,                             false",
+            "fun compare(hello: String) = Unit,                false",
+            "'fun compare(hello: String, world: Int) = Unit',  false"
+        )
+        fun `When toString without package`(code: String, result: Boolean) {
+            val (function, bindingContext) = buildKtFunction(env, code, false)
+            val methodSignature = FunctionMatcher.fromFunctionSignature("toString")
+            assertThat(methodSignature.match(function, bindingContext)).isEqualTo(result)
+        }
+
         @DisplayName("When toString()")
         @ParameterizedTest(name = "in case {0} it return {1}")
         @CsvSource(
@@ -187,6 +205,22 @@ class FunctionMatcherSpec(private val env: KotlinCoreEnvironment) {
             assertThat(methodSignature.match(function, bindingContext)).isEqualTo(result)
         }
 
+        @DisplayName("When toString(String)")
+        @ParameterizedTest(name = "in case {0} it return {1}")
+        @CsvSource(
+            "fun toString() = Unit,                            false",
+            "fun toString(hello: String) = Unit,               false",
+            "'fun toString(hello: String, world: Int) = Unit', false",
+            "fun compare() = Unit,                             false",
+            "fun compare(hello: String) = Unit,                false",
+            "'fun compare(hello: String, world: Int) = Unit',  false"
+        )
+        fun `When toString(String) without package`(code: String, result: Boolean) {
+            val (function, bindingContext) = buildKtFunction(env, code, false)
+            val methodSignature = FunctionMatcher.fromFunctionSignature("toString(String)")
+            assertThat(methodSignature.match(function, bindingContext)).isEqualTo(result)
+        }
+
         @DisplayName("When lambdas foo(() -> kotlin.String)")
         @ParameterizedTest(name = "in case {0} it return {1}")
         @CsvSource(
@@ -261,6 +295,48 @@ class FunctionMatcherSpec(private val env: KotlinCoreEnvironment) {
             val methodSignature = FunctionMatcher.fromFunctionSignature("foo(T, U)")
             assertThat(methodSignature.match(function, bindingContext)).isEqualTo(result)
         }
+
+        @ParameterizedTest
+        @CsvSource(
+            "fun bar(), class BarClass, io.github.detekt.BarClass.bar, true",
+            "fun bar(p: String), class BarClass, io.github.detekt.BarClass.bar, true",
+            "fun bar(p: T), class BarClass<T>, io.github.detekt.BarClass.bar, true",
+            "fun T.bar(), class BarClass<T>, io.github.detekt.BarClass.bar, true",
+
+            "fun bar(), class BarClass, io.github.detekt.BarClass.bar(), true",
+            "fun bar(p: String), class BarClass, io.github.detekt.BarClass.bar(kotlin.String), true",
+            "fun bar(p: T), class BarClass<T>, io.github.detekt.BarClass.bar(T), true",
+            "fun T.bar(), class BarClass<T>, io.github.detekt.BarClass.bar(T), true",
+            "'fun <V> bar(p1: V, p2: T)', class BarClass<T>, 'io.github.detekt.BarClass.bar(V, T)', true",
+
+            "fun bar(), class BarClass, io.github.detekt.BarClass.bar(kotlin.String), false",
+            "fun bar(p: String), class BarClass, io.github.detekt.BarClass.bar(kotlin.Int), false",
+            "fun bar(p: T), class BarClass, io.github.detekt.BarClass.bar(T), false",
+            "fun T.bar(), class BarClass, io.github.detekt.BarClass.bar(T), false",
+            "'fun <V> bar(p1: V, p2: T)', class BarClass<T>, 'io.github.detekt.BarClass.bar(T, V)', false",
+        )
+        fun `When function signature is fully qualified and declaration is enclosed into class`(
+            functionSignature: String,
+            classSignature: String,
+            pattern: String,
+            result: Boolean
+        ) {
+            val ktFile = compileContentForTest(
+                """
+                    package io.github.detekt
+
+                    $classSignature {
+                        $functionSignature {}
+                    }
+                """.trimIndent()
+            )
+            val bindingContext = env.getContextForPaths(listOf(ktFile))
+            val function = ktFile.findChildByClass(KtClass::class.java)!!
+                .findFunctionByName("bar") as KtNamedFunction
+
+            val methodSignature = FunctionMatcher.fromFunctionSignature(pattern)
+            assertThat(methodSignature.match(function, bindingContext)).isEqualTo(result)
+        }
     }
 }
 
@@ -270,8 +346,17 @@ private class TestCase(
     val expectedFunctionMatcher: FunctionMatcher,
 )
 
-private fun buildKtFunction(environment: KotlinCoreEnvironment, code: String): Pair<KtNamedFunction, BindingContext> {
-    val ktFile = compileContentForTest(code)
+private fun buildKtFunction(
+    environment: KotlinCoreEnvironment,
+    code: String,
+    includePackage: Boolean = true
+): Pair<KtNamedFunction, BindingContext> {
+    val ktFile = compileContentForTest(
+        """
+            ${if (includePackage) "package io.github.detekt" else ""}
+            $code
+        """.trimIndent()
+    )
     val bindingContext = environment.getContextForPaths(listOf(ktFile))
     return ktFile.findChildByClass(KtNamedFunction::class.java)!! to bindingContext
 }
